@@ -1,15 +1,5 @@
 """Configure application-wide logging to the command-line.
 
-Notes
------
-When a module in this package is imported, this __init__.py file is
-implicitly executed (as in the case of the entry point). If this code
-is not executed (as in the case of `python -m pyimgutil`), no logging
-will be performed.
-
-This logging setup is here, as opposed to elsewhere, because it greatly
-simplifies using `__name__` to name individual loggers.
-
 Copyright (C) 2021 emerac
 
 This program is free software: you can redistribute it and/or modify
@@ -28,14 +18,11 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 import logging
 
-# Each module's logger inherits its configuration from this logger.
 # The level will be set and the handlers added by other functions.
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter(
-    "%(name)-32s %(relativeCreated)6d %(levelname)-8s %(message)s"
+    "%(relativeCreated)6d %(levelname)-8s %(message)s"
 )
-# Used when the 'verbose' option is set.
 stream_handler = logging.StreamHandler()
 stream_handler.setFormatter(formatter)
-# Used when the 'quiet' option is set.
 null_handler = logging.NullHandler()
