@@ -120,6 +120,7 @@ def perform_command(im: Image, args: argparse.Namespace) -> Image:
     """
     if args.command == "convert":
         mod_im = im
+        logger.info("File converted.")
     if args.command == "crop":
         mod_im = commands.crop_image(
             im,
@@ -128,6 +129,7 @@ def perform_command(im: Image, args: argparse.Namespace) -> Image:
             args.upper,
             args.bottom,
         )
+        logger.info("File cropped.")
     if args.command == "resize":
         mod_im = commands.resize_image(
             im,
@@ -136,6 +138,13 @@ def perform_command(im: Image, args: argparse.Namespace) -> Image:
             args.scale,
             args.ratio,
         )
+        logger.info("File resized.")
+    if args.command == "rotate":
+        mod_im = commands.rotate_image(im, args.angle, args.fill)
+        logger.info("File rotated.")
+    if args.command == "transpose":
+        mod_im = commands.transpose_image(im)
+        logger.info("File transposed.")
     return mod_im
 
 
@@ -170,12 +179,12 @@ def main(argv: Optional[List[str]] = None) -> None:
         else:
             print(f"For help, try `pyimgutil {args.command} -h`.")
         sys.exit()
-    logger.info("All arguments are valid.")
+    logger.info("Proceeding with the provided arguments.")
 
     logger.info("Retrieving input files.")
     input_files = []
     for path in args.input:
-        logger.debug(f"Retrieving from: {path}")
+        logger.debug(f"Retrieving input: {path}")
         try:
             files_found = commands.get_valid_files(path, args.recursive)
         except ValueError as e:
